# Table of Contents

- [collections](<./collections.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Collections](<./Collections.md>)
  - [Overview](<./Collections/Overview.md>)
  - [Collection Structure](<./Collections/Collection-Structure.md>)
  - [Permissions](<./Collections/Permissions.md>)
  - [Using Collections](<./Collections/Using-Collections.md>)
  - [Managing Collections](<./Collections/Managing-Collections.md>)
  - [Importing Collections](<./Collections/Importing-Collections.md>)
  - [Best Practice](<./Collections/Best-Practice.md>)
  - [Was this page helpful?](<./Collections/Was-this-page-helpful.md>)
